#
# spec file for package budgie-desktop-view
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020 Callum Farmer <gmbr3@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} < 1550
%define _distconfdir %{_sysconfdir}
%endif
%define org org.buddiesofbudgie
Name:           budgie-desktop-view
Version:        1.3+0
Release:        3.3
Summary:        Official Budgie Desktop icons application / implementation
License:        Apache-2.0
Group:          System/GUI/Other
URL:            https://github.com/BuddiesOfBudgie/budgie-desktop-view
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.64.0

%description
Budgie Desktop View is the official Budgie desktop icons application / implementation

%lang_package

%prep
%autosetup

%build
# Handle poor vala code
export CFLAGS="%{optflags} -Wno-error"
# vala: Permit GNU C
export CFLAGS="${CFLAGS} -Wno-pedantic"
%meson -Dxdg-appdir=%{_distconfdir}/xdg/autostart
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%license LICENSE.md
%{_bindir}/%{org}.budgie-desktop-view
%{_distconfdir}/xdg/autostart/%{org}.budgie-desktop-view-autostart.desktop
%{_datadir}/applications/%{org}.budgie-desktop-view.desktop
%{_datadir}/glib-2.0/schemas/%{org}.budgie-desktop-view.gschema.xml

%files lang -f %{name}.lang

%changelog
* Fri Apr 12 2024 Callum Farmer <gmbr3@opensuse.org>
- Fixes for vala building code incompatible with Werror
* Thu Feb  1 2024 Callum Farmer <gmbr3@opensuse.org>
- Move autostart back to %%_distconfdir as aaa_base is fixed
* Fri Nov 24 2023 gmbr3@opensuse.org
- Update to version 1.3+0:
  * Bump to 1.3
  * Update translations
  * Make hover selection more obvious, tie in loading cursor.
  * Ensure Budgie Desktop View updates position
    and geometry on root window workarea change.
  * Add CODEOWNERS
  * Set focus to first VISIBLE item on arrow key press
  * Don't specify the file manager for trash icon
  * meson: Remove non standard optimization logic
  * Add translation support for trash icon
  * mesonPostInstall.sh: make update-desktop-database's
    target directory explicit
  * drop all support code for creating config.h
  * Use correct path for building xdg_appdir value.
  * Rename amd64 builds
  * Enable dependency caching, only do Ubuntu multiarch builds
  * Try to fix risc-v matrix
* Sun Feb  5 2023 gmbr3@opensuse.org
- Update to version 1.2.1+0:
  * Handle the new BDS desktop file naming in B-D master
  * Use arrow instead of HAND1
  * Remove unused gtk-update-icon-cache
  * Implement translations support using the budgie-desktop-view
    transifex project
  * Add updatePot and updateTranslations scripts
  * Move mkrelease.sh to scripts/mkRelease.sh
  * Add editorconfig
* Mon Aug 29 2022 Callum Farmer <gmbr3@opensuse.org>
- Move autostart back to /etc until aaa_base is fixed
* Tue Mar  8 2022 gmbr3@opensuse.org
- Update to version 1.2+0:
  * Tag 1.2 stable release
  * Set up directory for translations
  * Add FUNDING.yml
  * Link to releases page from release badge
  * Add Matrix and backer badges
  * Add GitHub Actions pipeline
  * Update comment and warning
  * Update to Budgie Control Center
  * Remove "GTK4 Port" from TODO
  * Fix launching of some file types.
* Fri Jan  7 2022 gmbr3@opensuse.org
- Update to version 1.1.1+5:
  * Rename schemas
  * Rebrand.
  * Update README to point to Open Collective and libera IRC
    channels
  * Enable application and key files to be moved to trash.
  * Update copyright to 2021
* Sat Oct 16 2021 Callum Farmer <gmbr3@opensuse.org>
- clean spec file
* Fri Dec 25 2020 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.1.1:
  * Check if it is a special item before deleting
* Wed Dec 23 2020 Callum Farmer <gmbr3@opensuse.org>
- Update to version 1.1:
  * Drag and Drop support
  * Keyboard-assisted navigation
  * Add Move to Trash button
  * Changed max thumbnail size from 1MB to 10MB
* Sat Nov 28 2020 Callum Farmer <gmbr3@opensuse.org>
- Initial packaging version 1.0.2
